==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/VirtualNodeSpecBackendVirtualServiceClientPolicyTlsCertificate.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property file Local file certificate.
 * @property sds A [Secret Discovery Service](https://www.envoyproxy.io/docs/envoy/latest/configuration/security/secret#secret-discovery-service-sds) certificate.
 */
public data class VirtualNodeSpecBackendVirtualServiceClientPolicyTlsCertificate(
    public val `file`: VirtualNodeSpecBackendVirtualServiceClientPolicyTlsCertificateFile? = null,
    public val sds: VirtualNodeSpecBackendVirtualServiceClientPolicyTlsCertificateSds? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.VirtualNodeSpecBackendVirtualServiceClientPolicyTlsCertificate):
            VirtualNodeSpecBackendVirtualServiceClientPolicyTlsCertificate =
            VirtualNodeSpecBackendVirtualServiceClientPolicyTlsCertificate(
                `file` = javaType.`file`().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.VirtualNodeSpecBackendVirtualServiceClientPolicyTlsCertificateFile.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                sds = javaType.sds().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.VirtualNodeSpecBackendVirtualServiceClientPolicyTlsCertificateSds.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/VirtualNodeSpecBackendVirtualServiceClientPolicyTlsCertificate.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property file Local file certificate.
 * @property sds A [Secret Discovery Service](https://www.envoyproxy.io/docs/envoy/latest/configuration/security/secret#secret-discovery-service-sds) certificate.
 */
public data class VirtualNodeSpecBackendVirtualServiceClientPolicyTlsCertificate(
    public val `file`: VirtualNodeSpecBackendVirtualServiceClientPolicyTlsCertificateFile? = null,
    public val sds: VirtualNodeSpecBackendVirtualServiceClientPolicyTlsCertificateSds? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.VirtualNodeSpecBackendVirtualServiceClientPolicyTlsCertificate): VirtualNodeSpecBackendVirtualServiceClientPolicyTlsCertificate =
            VirtualNodeSpecBackendVirtualServiceClientPolicyTlsCertificate(
                `file` = javaType.`file`().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.VirtualNodeSpecBackendVirtualServiceClientPolicyTlsCertificateFile.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                sds = javaType.sds().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.VirtualNodeSpecBackendVirtualServiceClientPolicyTlsCertificateSds.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}
